@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2019-2020 BigML
+# Copyright 2019-2021 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -157,7 +157,7 @@ def compute_output(api, args):
               [label.strip() for label in
                args.labels.split(args.args_separator)])
     if labels is not None:
-        labels = sorted([label for label in labels])
+        labels = sorted(labels)
 
     # multi_label file must be preprocessed to obtain a new extended file
     if args.multi_label and args.training_set is not None:
