@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2020 BigML
+# Copyright 2012-2021 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -24,7 +24,7 @@ import json
 import numbers
 import math
 
-from bigml.util import slugify
+from bigml.tree_utils import slugify
 
 import bigmler.utils as u
 import bigmler.resourcesapi.evaluations as r
