@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2020 BigML
+# Copyright 2014-2021 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -94,13 +94,6 @@ def get_source_options(defaults=None):
             'default': defaults.get('train_header', True),
             'help': "The train set file has a header."},
 
-        # Shows progress information when uploading a file.
-        '--progress-bar': {
-            'action': 'store_true',
-            'dest': 'progress_bar',
-            'default': defaults.get('progress_bar', False),
-            'help': "Show progress details when creating a source."},
-
         # Locale settings.
         '--locale': {
             'action': 'store',
@@ -116,14 +109,6 @@ def get_source_options(defaults=None):
             'help': ("Path to a json file describing source"
                      " attributes.")},
 
-        # Hides progress information when uploading a file. (opposed to
-        # --progress-bar)
-        '--no-progress-bar': {
-            'action': 'store_false',
-            'dest': 'progress_bar',
-            'default': defaults.get('progress_bar', False),
-            'help': "Show progress details when creating a source."},
-
         # Training set field separator. Defaults to the locale csv
         # separator.
         '--training-separator': {
