@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2020 BigML
+# Copyright 2014-2021 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -77,13 +77,12 @@ def get_categories_distribution(dataset, objective_id):
                 if 'categories' in summary:
                     distribution = summary['categories']
             return distribution
-        elif dataset_info['objective_field']['optype'] == 'text':
+        if dataset_info['objective_field']['optype'] == 'text':
             summary = dataset_info['fields'][objective_id]['summary']
             if 'tag_cloud' in summary:
                 distribution = summary['tag_cloud']
             return distribution
-        else:
-            return []
+        return []
     except KeyError:
         return []
 
