@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2015-2020 BigML
+# Copyright 2015-2021 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -205,7 +205,7 @@ def reify_resources(args, api):
         write_nb_output(resource_id, \
             exe_output, args.output.replace(".py", ".ipynb"), api)
         return
-    elif args.language == "whizzml":
+    if args.language == "whizzml":
         output = exe_output["source_code"]
         args.output = args.output.replace(".py", ".whizzml")
         exe_output["source_code"] = args.output
