@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2020 BigML
+# Copyright 2020-2021 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -103,8 +103,7 @@ def create_source(data_set, source_args, args, api=None, path=None,
     message = dated("Creating %ssource.\n" % suffix)
     log_message(message, log_file=session_file, console=args.verbosity)
     check_fields_struct(source_args, "source")
-    source = api.create_source(data_set, source_args,
-                               progress_bar=args.progress_bar)
+    source = api.create_source(data_set, source_args)
     if path is not None:
         suffix = "_" + source_type if source_type else ""
         log_created_resources(
