@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #!/usr/bin/env python
 #
-# Copyright 2020 BigML
+# Copyright 2020-2021 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -91,7 +91,7 @@ class TestExternalConnector(object):
             ['my connection', 'postgresql', HOST,
             PORT, USER, PASSWORD, DATABASE, 'scenario_41',
             'my new connection', 'scenario_41/my_connector.json',
-            'select * from rnacen.auth_group']]
+            'select * from iris']]
         for example in examples:
             print("\nTesting with:\n", example)
             external_connection.i_create_external_connector( \
