@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2020 BigML
+# Copyright 2012-2021 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -26,12 +26,12 @@ import sys
 from bigml.util import get_csv_delimiter
 from bigml.io import UnicodeReader
 
-from bigmler.utils import FILE_ENCODING, BIGML_SYS_ENCODING
+from bigmler.utils import BIGML_SYS_ENCODING
 from bigmler.checkpoint import file_number_of_lines
 from bigmler.utf8recoder import UTF8Recoder
 
 
-class TstReader(object):
+class TstReader():
     """Retrieves csv info and builds a input data dict
 
     """
